/*
Version 1
Planned features:
	Exclude files from becoming part of the menu based on an extension list (such as .bak files)
	Add a popup menu which lists open windows and lets you switch to one
	Add a popup menu which lists recent files and folders
	Add a popup menu which lists your recently chosen menu items
	Append the most recently chosen menu item to the top of the main popup menu
	Add option to hide file extensions in the displayed menu
	Monitor if the popup menu loses focus in a separate script and close the menu if it does (this would fix the problem of the menu staying open sometimes due to focus-stealing)
	Use a nicer icon for folders
	Improve menu scrolling spreed when the menu extends past the screen height
	Hide the shortcut arrow on .lnk shortcut file icons
*/

#SingleInstance Force
#Persistent
SetBatchLines, -1

#Include %A_ScriptDir%\Functions\WatchFolder.ahk
#Include %A_ScriptDir%\Functions\ExtractIcon.ahk

; Config
rootdir = %A_Appdata%\Microsoft\Internet Explorer\Quick Launch		; Change The Directory Path Here

GoSub CreateMenu
WatchFolder(rootdir, "Update", SubTree := True, Watch := 0x03)
Return

XButton2::
#z::
	gosub, ShowMenu
return

Update(Folder, Changes) {
	GoSub CreateMenu
}

CreateMenu:
	Menu, %rootdir%, add, Open %rootdir%, OpenFolder
	ExtractIcon(rootdir, "Open " . rootdir)
	
	Loop, %rootdir%\*.*, 2, 1 ; Folders only
	{
		if A_LoopFileAttrib contains H,R,S  ; Skip any file that is either H (Hidden), R (Read-only), or S (System). Note: No spaces in "H,R,S".
		continue  ; Skip this file and move on to the next one.
		StringGetPos, pos, A_LoopFileLongPath, \, R
		if (pos <> -1) ; it has a parent
			StringLeft, ParentFolderDirectory, A_LoopFileLongPath, %pos%
		if (pos = -1) ; it has no parent 
			ParentFolderDirectory := rootdir
		Menu, %A_LoopFileLongPath%, add, Open %A_LoopFileName%, OpenFolder
		ExtractIcon(A_LoopFileLongPath, "Open " . A_LoopFileName)
		Menu, %ParentFolderDirectory%, add, %A_LoopFileName%, :%A_LoopFileLongPath%
		ExtractIcon(ParentFolderDirectory, A_LoopFileName)
	}
		

	Loop, %rootdir%\*.*, 0, 1 ; Files only
	{
		;msgbox % A_LoopFileLongPath
		if A_LoopFileAttrib contains H,R,S  ; Skip any file that is either H (Hidden), R (Read-only), or S (System). Note: No spaces in "H,R,S".
		continue  ; Skip this file and move on to the next one.
		StringGetPos, pos, A_LoopFileLongPath, \, R
		if (pos <> -1) ; it has a parent
			StringLeft, ParentFolderDirectory, A_LoopFileLongPath, %pos%
		if (pos = -1) ; it has no parent 
			ParentFolderDirectory := rootdir
		Menu, %ParentFolderDirectory%, add, %A_LoopFileName%, OpenFile
		ExtractIcon(ParentFolderDirectory, A_LoopFileName)
	}
Return

OpenFile:
	run %A_ThisMenu%\%A_ThisMenuItem%
return

OpenFolder:
	run %A_ThisMenu%
return

ShowMenu:
	Menu, %rootdir%, Show
return